@@ -163,7 +163,7 @@ Example:
 
 You can listen for signals using a signal watcher, C<signal> is the signal
 I<name> without any C<SIG> prefix. Multiple signals events can be clumped
-together into one callback invocation, and callbakc invocation might or
+together into one callback invocation, and callback invocation might or
 might not be asynchronous.
 
 These watchers might use C<%SIG>, so programs overwriting those signals
@@ -247,9 +247,10 @@ package AnyEvent;
 
 no warnings;
 use strict;
+
 use Carp;
 
-our $VERSION = '2.51';
+our $VERSION = '2.54';
 our $MODEL;
 
 our $AUTOLOAD;
@@ -388,12 +389,14 @@ sub child {
    $PID_CB{$pid}{$arg{cb}} = $arg{cb};
 
    unless ($WNOHANG) {
-      $CHLD_W = AnyEvent->signal (signal => 'CHLD', cb => \&_child_wait);
       $WNOHANG = eval { require POSIX; &POSIX::WNOHANG } || 1;
    }
 
-   # child could be a zombie already
-   $PID_IDLE ||= AnyEvent->timer (after => 0, cb => \&_child_wait);
+   unless ($CHLD_W) {
+      $CHLD_W = AnyEvent->signal (signal => 'CHLD', cb => \&_child_wait);
+      # child could be a zombie already
+      $PID_IDLE ||= AnyEvent->timer (after => 0, cb => \&_child_wait);
+   }
 
    bless [$pid, $arg{cb}], "AnyEvent::Base::Child"
 }
@@ -439,7 +442,7 @@ I<rxvt-unicode> distribution.
 I<rxvt-unicode> also cheats a bit by not providing blocking access to
 condition variables: code blocking while waiting for a condition will
 C<die>. This still works with most modules/usages, and blocking calls must
-not be in an interactive appliation, so it makes sense.
+not be in an interactive application, so it makes sense.
 
 =head1 ENVIRONMENT VARIABLES
 
